PyXMake Developer Guide: PyXMake.VTL Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Namespaces | Classes | Functions | Variables
PyXMake.VTL Namespace Reference

Module containing virtual testing & benchmark scripts. More...

## Namespaces
namespace | __install__
| Install minimum working example scripts from PyXMake.
namespace | abaqus
namespace | api
namespace | app
namespace | archive
namespace | bundle
namespace | chocolatey
namespace | cmake
namespace | coverage
namespace | cxx
namespace | docker
namespace | doxygen
namespace | gfortran
namespace | gitlab
namespace | ifort
namespace | java
namespace | latex
namespace | openapi
namespace | portainer
namespace | py2x
namespace | pyreq
namespace | sphinx
namespace | ssh_f2py
namespace | ssh_ifort
namespace | ssh_make
namespace | stm_cara
namespace | stm_make
| Start build jobs on the Jenkins Test Server using PyXMake.
namespace | stm_post
| Post-processing build jobs on Jenkins2 using PyXMake.
namespace | stm_svn2git

## Classes
class | Command
| Parent class inherited from built-in exception. More...

## Functions
| GetSourceCode (key_opt=0)
| GetPreprocessingCommand (pre_opt=0)
| GetBuildCommand (make_opt=0, _format="fixed", _arch=Utility.GetArchitecture())
| GetIncludeDirectory (base_path, key_opt=0, make_opt=0, architecture="x64")
| GetLinkDependency (key_opt=0, make_opt=0, architecture="x64")
| GetEnvironment (env_opt=0)

## Variables
| Scratch = tempfile.gettempdir() if getattr(sys,"frozen",False) or Utility.IsDockerContainer() else os.path.join(os.path.dirname(os.path.abspath(__file__)),"scratch")
| func = x.split(".")[0]

## Detailed Description

Module containing virtual testing & benchmark scripts.

    Module containing virtual testing & benchmark scripts.

    @note: PyXMake module
    Created on 20.03.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Author
  Marc Garbade

Date
  18.03.2019

Notes/Changes
  - Added documentation // mg 18.03.2019
  - Renamed VTC with VTL // mg 04.04.2019

## Function Documentation

## ◆ GetBuildCommand()

PyXMake.VTL.GetBuildCommand | ( |  | make_opt = 0,
|  |  | _format = "fixed",
|  |  | _arch = Utility.GetArchitecture() )

    Return the recommended command line during the build process for selected make operations.

    @param: make_opt: An integer value representing the make operation.
    @type: make_opt: integer

Definition at line 404 of file __init__.py.

## ◆ GetEnvironment()

PyXMake.VTL.GetEnvironment | ( |  | env_opt = 0 | ) |

    Return predefined source environment to initiate a build process.

    @param: env_opt An integer value representing a predefined environment
    @type: env_opt: integer

Definition at line 699 of file __init__.py.

## ◆ GetIncludeDirectory()

PyXMake.VTL.GetIncludeDirectory | ( |  | base_path,
|  |  | key_opt = 0,
|  |  | make_opt = 0,
|  |  | architecture = "x64" )

    Return all mandatory include directories for the requested make operation in dependence of key_opt.

    @param: key_opt, make_opt: [An integer value representing the source code file (e.g. MCODAC, BoxBeam, BEOS),
                                                      An integer value representing the make operation.]
    @type: key_opt, make_opt: integer

Definition at line 595 of file __init__.py.

## ◆ GetLinkDependency()

PyXMake.VTL.GetLinkDependency | ( |  | key_opt = 0,
|  |  | make_opt = 0,
|  |  | architecture = "x64" )

    Return all mandatory external libraries for the requested make operation in dependence of key_opt.

    @param: key_opt, make_opt: [An integer value representing the source code file (e.g. MCODAC, BoxBeam, BEOS),
                                                      An integer value representing the make operation.]
    @type: key_opt, make_opt: integer

Definition at line 681 of file __init__.py.

## ◆ GetPreprocessingCommand()

PyXMake.VTL.GetPreprocessingCommand | ( |  | pre_opt = 0 | ) |

    Return the recommended preprocessor command line.

    @param: make_opt: An integer value representing or qualified name the requested  preprocessor
    @type: pre_opt: integer or string

Definition at line 380 of file __init__.py.

## ◆ GetSourceCode()

PyXMake.VTL.GetSourceCode | ( |  | key_opt = 0 | ) |

    Get a list of source codes files associated with the build of MCODAC, BoxBeam or BEOS.

    @param: key_opt: An integer value representing the source code files.
    @type: key_opt: integer

Definition at line 311 of file __init__.py.

## Variable Documentation

## ◆ func

PyXMake.VTL.func = x.split(".")[0]

Definition at line 748 of file __init__.py.

## ◆ Scratch

PyXMake.VTL.Scratch = tempfile.gettempdir() if getattr(sys,"frozen",False) or Utility.IsDockerContainer() else os.path.join(os.path.dirname(os.path.abspath(__file__)),"scratch")

Definition at line 46 of file __init__.py.